# Class: Feature

A new piece of functionality

## Fields for class: Feature

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`enabled`           |`bool`              |_RO/runtime_   |Indicates whether the feature is enabled|
|`experimental`      |`bool`              |_RO/constructor_|Indicates whether the feature is experimental &#40;as opposed to stable and fully supported&#41;|
|`host`              |`host ref`          |_RO/runtime_   |The host where this feature is available|
|`name_description`  |`string`            |_RO/constructor_|a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RO/constructor_|a human&#45;readable name               |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`version`           |`string`            |_RO/constructor_|The version of this feature             |

## RPCs associated with class: Feature

### RPC name: get&#95;all

_Overview:_

Return a list of all the Features known to the system.

_Signature:_

```
Feature ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `Feature ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of Feature references to Feature records for all Features known to the system.

_Signature:_

```
(Feature ref -> Feature record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(Feature ref -> Feature record) map`

records of all objects

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the Feature instances with the given label.

_Signature:_

```
Feature ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `Feature ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the Feature instance with the specified UUID.

_Signature:_

```
Feature ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `Feature ref`

reference to the object

### RPC name: get&#95;enabled

_Overview:_

Get the enabled field of the given Feature.

_Signature:_

```
bool get_enabled (session ref session_ref, Feature ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Feature ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;experimental

_Overview:_

Get the experimental field of the given Feature.

_Signature:_

```
bool get_experimental (session ref session_ref, Feature ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Feature ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;host

_Overview:_

Get the host field of the given Feature.

_Signature:_

```
host ref get_host (session ref session_ref, Feature ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Feature ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given Feature.

_Signature:_

```
string get_name_description (session ref session_ref, Feature ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Feature ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given Feature.

_Signature:_

```
string get_name_label (session ref session_ref, Feature ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Feature ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given Feature.

_Signature:_

```
Feature record get_record (session ref session_ref, Feature ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Feature ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Feature record`

all fields from the object

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given Feature.

_Signature:_

```
string get_uuid (session ref session_ref, Feature ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Feature ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;version

_Overview:_

Get the version field of the given Feature.

_Signature:_

```
string get_version (session ref session_ref, Feature ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Feature ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field
