# Class: network

A virtual network

## Fields for class: network

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`allowed_operations`|`network_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|`assigned_ips`      |`(VIF ref -> string) map`|_RO/runtime_   |The IP addresses assigned to VIFs on networks that have active xapi&#45;managed DHCP|
|`blobs`             |`(string -> blob ref) map`|_RO/runtime_   |Binary blobs associated with this network|
|`bridge`            |`string`            |_RO/constructor_|name of the bridge corresponding to this network on the local host|
|`current_operations`|`(string -> network_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|`default_locking_mode`|`network_default_locking_mode`|_RO/runtime_   |The network will use this value to determine the behaviour of all VIFs where locking&#95;mode = default|
|`managed`           |`bool`              |_RO/constructor_|true if the bridge is managed by xapi   |
|`MTU`               |`int`               |_RW_           |MTU in octets                           |
|`name_description`  |`string`            |_RW_           |a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RW_           |a human&#45;readable name               |
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`PIFs`              |`PIF ref set`       |_RO/runtime_   |list of connected pifs                  |
|`purpose`           |`network_purpose set`|_RO/runtime_   |Set of purposes for which the server will use this network|
|`tags`              |`string set`        |_RW_           |user&#45;specified tags for categorization purposes|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VIFs`              |`VIF ref set`       |_RO/runtime_   |list of connected vifs                  |

## RPCs associated with class: network

### RPC name: add&#95;purpose

_Overview:_

Give a network a new purpose &#40;if not present already&#41;

_Signature:_

```
void add_purpose (session ref session_ref, network ref self, network_purpose value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |The network                             |
|`network_purpose`             |`value`                       |The purpose to add                      |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

_Possible Error Codes:_ `NETWORK_INCOMPATIBLE_PURPOSES`

### RPC name: add&#95;tags

_Overview:_

Add the given value to the tags field of the given network.  If the value is already in that Set, then do nothing.

_Signature:_

```
void add_tags (session ref session_ref, network ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to add                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given network.

_Signature:_

```
void add_to_other_config (session ref session_ref, network ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: create

_Overview:_

Create a new network instance, and return its handle.

_Signature:_

```
network ref create (session ref session_ref, network record args)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network record`              |`args`                        |All constructor arguments               |

_Minimum Role:_ vm-admin

_Return Type:_ `network ref`

reference to the newly created object

### RPC name: create&#95;new&#95;blob

_Overview:_

Create a placeholder for a named binary blob of data that is associated with this pool

_Signature:_

```
blob ref create_new_blob (session ref session_ref, network ref network, string name, string mime_type, bool public)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`network`                     |The network                             |
|`string`                      |`name`                        |The name associated with the blob       |
|`string`                      |`mime_type`                   |The mime type for the data. Empty string translates to application/octet&#45;stream|
|`bool`                        |`public`                      |True if the blob should be publicly available|

_Minimum Role:_ pool-operator

_Return Type:_ `blob ref`

The reference of the blob, needed for populating its data

### RPC name: destroy

_Overview:_

Destroy the specified network instance.

_Signature:_

```
void destroy (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the networks known to the system.

_Signature:_

```
network ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `network ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of network references to network records for all networks known to the system.

_Signature:_

```
(network ref -> network record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(network ref -> network record) map`

records of all objects

### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given network.

_Signature:_

```
network_operations set get_allowed_operations (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network_operations set`

value of the field

### RPC name: get&#95;assigned&#95;ips

_Overview:_

Get the assigned&#95;ips field of the given network.

_Signature:_

```
(VIF ref -> string) map get_assigned_ips (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(VIF ref -> string) map`

value of the field

### RPC name: get&#95;blobs

_Overview:_

Get the blobs field of the given network.

_Signature:_

```
(string -> blob ref) map get_blobs (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> blob ref) map`

value of the field

### RPC name: get&#95;bridge

_Overview:_

Get the bridge field of the given network.

_Signature:_

```
string get_bridge (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the network instances with the given label.

_Signature:_

```
network ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `network ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the network instance with the specified UUID.

_Signature:_

```
network ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `network ref`

reference to the object

### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given network.

_Signature:_

```
(string -> network_operations) map get_current_operations (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> network_operations) map`

value of the field

### RPC name: get&#95;default&#95;locking&#95;mode

_Overview:_

Get the default&#95;locking&#95;mode field of the given network.

_Signature:_

```
network_default_locking_mode get_default_locking_mode (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network_default_locking_mode`

value of the field

### RPC name: get&#95;managed

_Overview:_

Get the managed field of the given network.

_Signature:_

```
bool get_managed (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;MTU

_Overview:_

Get the MTU field of the given network.

_Signature:_

```
int get_MTU (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given network.

_Signature:_

```
string get_name_description (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given network.

_Signature:_

```
string get_name_label (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given network.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;PIFs

_Overview:_

Get the PIFs field of the given network.

_Signature:_

```
PIF ref set get_PIFs (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref set`

value of the field

### RPC name: get&#95;purpose

_Overview:_

Get the purpose field of the given network.

_Signature:_

```
network_purpose set get_purpose (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network_purpose set`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given network.

_Signature:_

```
network record get_record (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network record`

all fields from the object

### RPC name: get&#95;tags

_Overview:_

Get the tags field of the given network.

_Signature:_

```
string set get_tags (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given network.

_Signature:_

```
string get_uuid (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VIFs

_Overview:_

Get the VIFs field of the given network.

_Signature:_

```
VIF ref set get_VIFs (session ref session_ref, network ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VIF ref set`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given network.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, network ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;purpose

_Overview:_

Remove a purpose from a network &#40;if present&#41;

_Signature:_

```
void remove_purpose (session ref session_ref, network ref self, network_purpose value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |The network                             |
|`network_purpose`             |`value`                       |The purpose to remove                   |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: remove&#95;tags

_Overview:_

Remove the given value from the tags field of the given network.  If the value is not in that Set, then do nothing.

_Signature:_

```
void remove_tags (session ref session_ref, network ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |
|`string`                      |`value`                       |Value to remove                         |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: set&#95;default&#95;locking&#95;mode

_Overview:_

Set the default locking mode for VIFs attached to this network

_Signature:_

```
void set_default_locking_mode (session ref session_ref, network ref network, network_default_locking_mode value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`network`                     |The network                             |
|`network_default_locking_mode`|`value`                       |The default locking mode for VIFs attached to this network.|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;MTU

_Overview:_

Set the MTU field of the given network.

_Signature:_

```
void set_MTU (session ref session_ref, network ref self, int value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |
|`int`                         |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given network.

_Signature:_

```
void set_name_description (session ref session_ref, network ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given network.

_Signature:_

```
void set_name_label (session ref session_ref, network ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given network.

_Signature:_

```
void set_other_config (session ref session_ref, network ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;tags

_Overview:_

Set the tags field of the given network.

_Signature:_

```
void set_tags (session ref session_ref, network ref self, string set value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`self`                        |reference to the object                 |
|`string set`                  |`value`                       |New value to set                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`
