# Class: PGPU

A physical GPU &#40;pGPU&#41;

## Fields for class: PGPU

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`compatibility_metadata`|`(string -> string) map`|_RO/runtime_   |PGPU metadata to determine whether a VGPU can migrate between two PGPUs|
|`dom0_access`       |`pci_dom0_access`   |_RO/runtime_   |**Deprecated.** The accessibility of this device from dom0|
|`enabled_VGPU_types`|`VGPU_type ref set` |_RO/runtime_   |List of VGPU types which have been enabled for this PGPU|
|`GPU_group`         |`GPU_group ref`     |_RO/constructor_|GPU group the pGPU is contained in      |
|`host`              |`host ref`          |_RO/runtime_   |Host that owns the GPU                  |
|`is_system_display_device`|`bool`              |_RO/runtime_   |Is this device the system display device|
|`other_config`      |`(string -> string) map`|_RW_           |Additional configuration                |
|`PCI`               |`PCI ref`           |_RO/constructor_|Link to underlying PCI device           |
|`resident_VGPUs`    |`VGPU ref set`      |_RO/runtime_   |List of VGPUs running on this PGPU      |
|`supported_VGPU_max_capacities`|`(VGPU_type ref -> int) map`|_RO/runtime_   |A map relating each VGPU type supported on this GPU to the maximum number of VGPUs of that type which can run simultaneously on this GPU|
|`supported_VGPU_types`|`VGPU_type ref set` |_RO/runtime_   |List of VGPU types supported by the underlying hardware|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: PGPU

### RPC name: add&#95;enabled&#95;VGPU&#95;types

_Overview:_

_Signature:_

```
void add_enabled_VGPU_types (session ref session_ref, PGPU ref self, VGPU_type ref value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |The PGPU to which we are adding an enabled VGPU type|
|`VGPU_type ref`               |`value`                       |The VGPU type to enable                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given PGPU.

_Signature:_

```
void add_to_other_config (session ref session_ref, PGPU ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: disable&#95;dom0&#95;access

**This message is deprecated.**

_Overview:_

_Signature:_

```
pci_dom0_access disable_dom0_access (session ref session_ref, PGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |The PGPU to which dom0 will be denied access|

_Minimum Role:_ pool-operator

_Return Type:_ `pci_dom0_access`

The accessibility of this PGPU from dom0

### RPC name: enable&#95;dom0&#95;access

**This message is deprecated.**

_Overview:_

_Signature:_

```
pci_dom0_access enable_dom0_access (session ref session_ref, PGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |The PGPU to which dom0 will be granted access|

_Minimum Role:_ pool-operator

_Return Type:_ `pci_dom0_access`

The accessibility of this PGPU from dom0

### RPC name: get&#95;all

_Overview:_

Return a list of all the PGPUs known to the system.

_Signature:_

```
PGPU ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PGPU references to PGPU records for all PGPUs known to the system.

_Signature:_

```
(PGPU ref -> PGPU record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(PGPU ref -> PGPU record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PGPU instance with the specified UUID.

_Signature:_

```
PGPU ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref`

reference to the object

### RPC name: get&#95;compatibility&#95;metadata

_Overview:_

Get the compatibility&#95;metadata field of the given PGPU.

_Signature:_

```
(string -> string) map get_compatibility_metadata (session ref session_ref, PGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;dom0&#95;access

**This message is deprecated.**

_Overview:_

Get the dom0&#95;access field of the given PGPU.

_Signature:_

```
pci_dom0_access get_dom0_access (session ref session_ref, PGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pci_dom0_access`

value of the field

### RPC name: get&#95;enabled&#95;VGPU&#95;types

_Overview:_

Get the enabled&#95;VGPU&#95;types field of the given PGPU.

_Signature:_

```
VGPU_type ref set get_enabled_VGPU_types (session ref session_ref, PGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref set`

value of the field

### RPC name: get&#95;GPU&#95;group

_Overview:_

Get the GPU&#95;group field of the given PGPU.

_Signature:_

```
GPU_group ref get_GPU_group (session ref session_ref, PGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `GPU_group ref`

value of the field

### RPC name: get&#95;host

_Overview:_

Get the host field of the given PGPU.

_Signature:_

```
host ref get_host (session ref session_ref, PGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

### RPC name: get&#95;is&#95;system&#95;display&#95;device

_Overview:_

Get the is&#95;system&#95;display&#95;device field of the given PGPU.

_Signature:_

```
bool get_is_system_display_device (session ref session_ref, PGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given PGPU.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, PGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;PCI

_Overview:_

Get the PCI field of the given PGPU.

_Signature:_

```
PCI ref get_PCI (session ref session_ref, PGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PCI ref`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PGPU.

_Signature:_

```
PGPU record get_record (session ref session_ref, PGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PGPU record`

all fields from the object

### RPC name: get&#95;remaining&#95;capacity

_Overview:_

_Signature:_

```
int get_remaining_capacity (session ref session_ref, PGPU ref self, VGPU_type ref vgpu_type)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |The PGPU to query                       |
|`VGPU_type ref`               |`vgpu_type`                   |The VGPU type for which we want to find the number of VGPUs which can still be started on this PGPU|

_Minimum Role:_ read-only

_Return Type:_ `int`

The number of VGPUs of the specified type which can still be started on this PGPU

### RPC name: get&#95;resident&#95;VGPUs

_Overview:_

Get the resident&#95;VGPUs field of the given PGPU.

_Signature:_

```
VGPU ref set get_resident_VGPUs (session ref session_ref, PGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU ref set`

value of the field

### RPC name: get&#95;supported&#95;VGPU&#95;max&#95;capacities

_Overview:_

Get the supported&#95;VGPU&#95;max&#95;capacities field of the given PGPU.

_Signature:_

```
(VGPU_type ref -> int) map get_supported_VGPU_max_capacities (session ref session_ref, PGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(VGPU_type ref -> int) map`

value of the field

### RPC name: get&#95;supported&#95;VGPU&#95;types

_Overview:_

Get the supported&#95;VGPU&#95;types field of the given PGPU.

_Signature:_

```
VGPU_type ref set get_supported_VGPU_types (session ref session_ref, PGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref set`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PGPU.

_Signature:_

```
string get_uuid (session ref session_ref, PGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: remove&#95;enabled&#95;VGPU&#95;types

_Overview:_

_Signature:_

```
void remove_enabled_VGPU_types (session ref session_ref, PGPU ref self, VGPU_type ref value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |The PGPU from which we are removing an enabled VGPU type|
|`VGPU_type ref`               |`value`                       |The VGPU type to disable                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given PGPU.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, PGPU ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;enabled&#95;VGPU&#95;types

_Overview:_

_Signature:_

```
void set_enabled_VGPU_types (session ref session_ref, PGPU ref self, VGPU_type ref set value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |The PGPU on which we are enabling a set of VGPU types|
|`VGPU_type ref set`           |`value`                       |The VGPU types to enable                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;GPU&#95;group

_Overview:_

_Signature:_

```
void set_GPU_group (session ref session_ref, PGPU ref self, GPU_group ref value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |The PGPU to move to a new group         |
|`GPU_group ref`               |`value`                       |The group to which the PGPU will be moved|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given PGPU.

_Signature:_

```
void set_other_config (session ref session_ref, PGPU ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PGPU ref`                    |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
